#include "Gadget/Engine.h"
#include "Vehicle.h"

Core* Vehicle::G;

Vehicle::Vehicle()
{
	//Set default properties
	friction        =   2.0f;
	direction       =   0.0f;
	wanderDir       = float(rand()%360);
	maxAcceleration = 400.0f;
	maxVelocity     = 800.0f;
	maxRotation     = 180.0f;
	radius          = 100.0f;
}

void Vehicle::SetSteeringForce(Vector2D forceVec, Vector2D lookVec)
{
	//Limit acceleration rate
	if(forceVec.GetLength()>=1.0f) {forceVec.SetLength(1.0f);}
	forceVec = forceVec*maxAcceleration;
	this->forceVec = forceVec;

	this->lookVec = lookVec; //This vector is used to set the ship's rotation
}

void Vehicle::Step()
{
	//Friction
	velocity = velocity * (1.0f-friction*G->Timer.GetElapsedTime());
	//Update velocity based on acceleration
	velocity += forceVec*G->Timer.GetElapsedTime();

	//Limit velocity
	if(velocity.GetLengthSq()>maxVelocity*maxVelocity)
	{
		velocity.SetLength(maxVelocity);
	}

	position = position + velocity*G->Timer.GetElapsedTime();//Move the ship
	direction = RotateToward(direction, lookVec.VectorToAngle(lookVec), maxRotation*G->Timer.GetElapsedTime());//Rotate ship
}

void Vehicle::Collide(Vehicle &other)
{
	static Vector2D tempVec;
	static float tempF;

	tempF = (radius + other.radius);
	tempVec = position - other.position;
	tempF = tempVec.GetLength()-tempF;

	if(tempF<0.0f)
	{
		tempVec.Normalize();
		tempVec = tempVec * (tempF*0.5f);
		position += tempVec*-1.0f;
		other.position += tempVec;
	}
}

